@@ -11,11 +11,12 @@
 #include <reservationmanager.h>
 #include <documentmanager.h>
 #include <favoritelocationmodel.h>
-#include <healthcertificatemanager.h>
+#include <livedatamanager.h>
 #include <passmanager.h>
 #include <transfermanager.h>
 #include <tripgroupmanager.h>
 
+#include <KItinerary/DocumentUtil>
 #include <KItinerary/ExtractorCapabilities>
 #include <KItinerary/File>
 
@@ -28,12 +29,6 @@
 class AppControllerTest : public QObject
 {
     Q_OBJECT
-private:
-    bool hasZxing()
-    {
-        return KItinerary::ExtractorCapabilities::capabilitiesString().contains(QLatin1String("zxing"), Qt::CaseInsensitive);
-    }
-
 private Q_SLOTS:
     void initTestCase()
     {
@@ -56,7 +51,6 @@ private Q_SLOTS:
         DocumentManager docMgr;
         Test::clearAll(&docMgr);
 
-        HealthCertificateManager healthCertMgr;
         PassManager passMgr;
         Test::clearAll(&passMgr);
 
@@ -65,7 +59,6 @@ private Q_SLOTS:
         appController.setPkPassManager(&pkPassMgr);
         appController.setReservationManager(&resMgr);
         appController.setDocumentManager(&docMgr);
-        appController.setHealthCertificateManager(&healthCertMgr);
         appController.setPassManager(&passMgr);
 
         appController.importData(Test::readFile(QLatin1String(SOURCE_DIR "/data/4U8465-v1.json")));
@@ -81,9 +74,6 @@ private Q_SLOTS:
         QCOMPARE(pkPassSpy.size(), 1);
         QCOMPARE(infoSpy.size(), 3);
         appController.importData(Test::readFile(QLatin1String(SOURCE_DIR "/data/iata-bcbp-demo.pdf")));
-        if (!hasZxing()) {
-            QSKIP("Built without ZXing");
-        }
         QCOMPARE(resSpy.size(), 4);
         QCOMPARE(pkPassSpy.size(), 1);
         QCOMPARE(infoSpy.size(), 4);
@@ -111,7 +101,6 @@ private Q_SLOTS:
         DocumentManager docMgr;
         Test::clearAll(&docMgr);
 
-        HealthCertificateManager healthCertMgr;
         PassManager passMgr;
         Test::clearAll(&passMgr);
 
@@ -120,7 +109,6 @@ private Q_SLOTS:
         appController.setPkPassManager(&pkPassMgr);
         appController.setReservationManager(&resMgr);
         appController.setDocumentManager(&docMgr);
-        appController.setHealthCertificateManager(&healthCertMgr);
         appController.setPassManager(&passMgr);
 
         appController.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/4U8465-v1.json")));
@@ -132,9 +120,6 @@ private Q_SLOTS:
         QCOMPARE(pkPassSpy.size(), 1);
         QCOMPARE(infoSpy.size(), 2);
         appController.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/iata-bcbp-demo.pdf")));
-        if (!hasZxing()) {
-            QSKIP("Built without ZXing");
-        }
         QCOMPARE(resSpy.size(), 3);
         QCOMPARE(pkPassSpy.size(), 1);
         QCOMPARE(infoSpy.size(), 3);
@@ -163,7 +148,7 @@ private Q_SLOTS:
         PassManager passMgr;
         Test::clearAll(&passMgr);
 
-        HealthCertificateManager healthCertMgr;
+        LiveDataManager liveDataMgr;
 
         ApplicationController appController;
         QSignalSpy infoSpy(&appController, &ApplicationController::infoMessage);
@@ -173,7 +158,7 @@ private Q_SLOTS:
         appController.setTransferManager(&transferMgr);
         appController.setFavoriteLocationModel(&favLoc);
         appController.setPassManager(&passMgr);
-        appController.setHealthCertificateManager(&healthCertMgr);
+        appController.setLiveDataManager(&liveDataMgr);
 
         appController.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/4U8465-v1.json")));
         appController.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/boardingpass-v1.pkpass")));
@@ -221,6 +206,59 @@ private Q_SLOTS:
         QCOMPARE(passMgr.rowCount(), 1);
         QCOMPARE(infoSpy.size(), 6);
     }
+
+    void testDocumentAttaching()
+    {
+        ReservationManager resMgr;
+        Test::clearAll(&resMgr);
+        DocumentManager docMgr;
+        Test::clearAll(&docMgr);
+        PassManager passMgr;
+        Test::clearAll(&passMgr);
+        auto ctrl = Test::makeAppController();
+
+        ctrl->setReservationManager(&resMgr);
+        ctrl->setDocumentManager(&docMgr);
+        ctrl->setPassManager(&passMgr);
+
+        {
+            QCOMPARE(docMgr.documents().size(), 0);
+            ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/4U8465-v1.json")));
+            QCOMPARE(resMgr.batches().size(), 1);
+            const auto resId = resMgr.batches().at(0);
+
+            QCOMPARE(KItinerary::DocumentUtil::documentIds(resMgr.reservation(resId)).size(), 0);
+            ctrl->addDocumentToReservation(resId, QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/iata-bcbp-demo.pdf")));
+            QCOMPARE(docMgr.documents().size(), 1);
+            const auto docIds = KItinerary::DocumentUtil::documentIds(resMgr.reservation(resId));
+            QCOMPARE(docIds.size(), 1);
+
+            ctrl->removeDocumentFromReservation(resId, docIds.at(0).toString());
+            QCOMPARE(docMgr.documents().size(), 0);
+            QCOMPARE(resMgr.batches().size(), 1);
+            QCOMPARE(KItinerary::DocumentUtil::documentIds(resMgr.reservation(resId)).size(), 0);
+        }
+
+        {
+            QCOMPARE(passMgr.rowCount(), 0);
+            ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/9euroticket.json")));
+            QCOMPARE(docMgr.documents().size(), 0);
+            QCOMPARE(passMgr.rowCount(), 1);
+            const auto passId = passMgr.index(0, 0).data(PassManager::PassIdRole).toString();
+            auto docIds = KItinerary::DocumentUtil::documentIds(passMgr.pass(passId));
+            QCOMPARE(docIds.size(), 0);
+
+            ctrl->addDocumentToPass(passId, QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/iata-bcbp-demo.pdf")));
+            QCOMPARE(docMgr.documents().size(), 1);
+            docIds = KItinerary::DocumentUtil::documentIds(passMgr.pass(passId));
+            QCOMPARE(docIds.size(), 1);
+
+            ctrl->removeDocumentFromPass(passId, docIds.at(0).toString());
+            QCOMPARE(docMgr.documents().size(), 0);
+            QCOMPARE(passMgr.rowCount(), 1);
+            QCOMPARE(KItinerary::DocumentUtil::documentIds(passMgr.pass(passId)).size(), 0);
+        }
+    }
 };
 
 QTEST_GUILESS_MAIN(AppControllerTest)
