@@ -128,6 +128,11 @@ ApplicationController::~ApplicationController()
     s_instance = nullptr;
 }
 
+void ApplicationController::setNetworkAccessManagerFactory(const std::function<QNetworkAccessManager*()> &namFactory)
+{
+    m_namFactory = namFactory;
+}
+
 ApplicationController* ApplicationController::instance()
 {
     return s_instance;
@@ -308,10 +313,7 @@ void ApplicationController::importFromUrl(const QUrl &url)
     }
 
     if (url.scheme().startsWith(QLatin1String("http"))) {
-        if (!m_nam ) {
-            m_nam = new QNetworkAccessManager(this);
-        }
-        auto job = new DownloadJob(url, m_nam, this);
+        auto job = new DownloadJob(url, m_namFactory(), this);
         connect(job, &DownloadJob::finished, this, [this, job]() {
             job->deleteLater();
             if (job->hasError()) {
