@@ -23,7 +23,7 @@ public:
     ~HealthCertificateManager() override;
 
     /** Health certificate support is compiled in. */
-    bool isAvailable() const;
+    static bool isAvailable();
 
     bool importCertificate(const QByteArray &rawData);
     Q_INVOKABLE void removeCertificate(int row);
