@@ -12,12 +12,14 @@
 #include "livedata.h"
 #include "livedatamanager.h"
 #include "logging.h"
+#include "passmanager.h"
 #include "pkpassmanager.h"
 #include "reservationmanager.h"
 #include "transfer.h"
 #include "transfermanager.h"
 
 #include <KItinerary/File>
+#include <KItinerary/JsonLdDocument>
 
 #include <QFile>
 #include <QJsonArray>
@@ -96,6 +98,18 @@ void Exporter::exportFavoriteLocations(const FavoriteLocationModel* favLocModel)
     }
 }
 
+void Exporter::exportPasses(const PassManager *passMgr)
+{
+    for (int i = 0; i < passMgr->rowCount(); ++i) {
+        const auto idx = passMgr->index(i, 0);
+        m_file->addCustomData(
+            QStringLiteral("org.kde.itinerary/programs"),
+            passMgr->data(idx, PassManager::PassIdRole).toString(),
+            passMgr->data(idx, PassManager::PassDataRole).toByteArray()
+        );
+    }
+}
+
 void Exporter::exportHealthCertificates(const HealthCertificateManager *healthCertMgr)
 {
     for (int i = 0; i < healthCertMgr->rowCount(); ++i) {
@@ -200,6 +214,18 @@ int Importer::importFavoriteLocations(FavoriteLocationModel *favLocModel)
     return favLocs.size();
 }
 
+int Importer::importPasses(PassManager *passMgr)
+{
+    const auto domain = QStringLiteral("org.kde.itinerary/programs");
+    const auto ids = m_file->listCustomData(domain);
+    for (const auto &id : ids) {
+        const auto data = m_file->customData(domain, id);
+        const auto pass = KItinerary::JsonLdDocument::fromJsonSingular(QJsonDocument::fromJson(data).object());
+        passMgr->import(pass, id);
+    }
+    return ids.size();
+}
+
 int Importer::importHealthCertificates(HealthCertificateManager *healthCertMgr)
 {
     const auto domain = QStringLiteral("org.kde.itinerary/health-certificates");
