@@ -45,7 +45,7 @@ static QString readFromGadget(const QMetaObject *mo, const QVariant &gadget, con
     return prop.readOnGadget(gadget.constData()).toString();
 }
 
-QString Localizer::formatAddress(const QVariant &obj) const
+static KContacts::Address variantToKContactsAddress(const QVariant &obj)
 {
     KContacts::Address address;
     if (JsonLd::isA<PostalAddress>(obj)) {
@@ -62,11 +62,60 @@ QString Localizer::formatAddress(const QVariant &obj) const
         address.setLocality(readFromGadget(mo, obj, "city"));
         address.setRegion(readFromGadget(mo, obj, "state"));
         address.setCountry(readFromGadget(mo, obj, "country"));
-    } else {
+    }
+    return address;
+}
+
+QString Localizer::formatAddress(const QVariant &obj) const
+{
+    KContacts::Address address = variantToKContactsAddress(obj);
+    if (address.isEmpty()) {
+        return {};
+    }
+    return address.formatted(KContacts::AddressFormatStyle::MultiLineInternational);
+}
+
+static bool addressEmptyExceptForCountry(const KContacts::Address &address)
+{
+    return address.street().isEmpty() && address.locality().isEmpty()
+            && address.postalCode().isEmpty() && address.region().isEmpty()
+            && !address.country().isEmpty();
+}
+
+QString Localizer::formatAddressWithContext(const QVariant &obj, const QVariant &otherObj, const QString &homeCountryIsoCode)
+{
+    const KContacts::Address address = variantToKContactsAddress(obj);
+
+    if (address.isEmpty()) {
         return {};
     }
 
-    return address.formatted(KContacts::AddressFormatStyle::MultiLineInternational);
+    const bool includeCountry = [&] {
+        if (homeCountryIsoCode.isEmpty()) {
+            return true;
+        }
+
+        if (!addressEmptyExceptForCountry(address)) {
+            return true;
+        }
+
+        if (address.country() != homeCountryIsoCode) {
+            return true;
+        }
+
+        const KContacts::Address otherAddress = variantToKContactsAddress(otherObj);
+        if (!otherAddress.country().isEmpty() && address.country() != otherAddress.country()) {
+            return true;
+        }
+
+        return false;
+    }();
+
+    if (includeCountry) {
+        return address.formatted(KContacts::AddressFormatStyle::MultiLineInternational);
+    } else {
+        return address.formatted(KContacts::AddressFormatStyle::MultiLineDomestic);
+    }
 }
 
 static bool needsTimeZone(const QDateTime &dt)
@@ -108,11 +157,16 @@ QString Localizer::formatTime(const QVariant &obj, const QString &propertyName)
         return {};
     }
 
-    auto s = QLocale().toString(dt.time(), QLocale::ShortFormat);
-    if (needsTimeZone(dt)) {
-        s += QLatin1Char(' ') + tzAbbreviation(dt);
+    QString output;
+    if (QLocale().timeFormat(QLocale::ShortFormat).contains(QStringLiteral("ss"))) {
+        output = QLocale().toString(dt.time(), QStringLiteral("hh:mm"));
+    } else {
+        output = QLocale().toString(dt.time(), QLocale::ShortFormat);
     }
-    return s;
+    if (needsTimeZone(dt)) {
+        output += QLatin1Char(' ') + tzAbbreviation(dt);
+    }
+    return output;
 }
 
 QString Localizer::formatDate(const QVariant &obj, const QString &propertyName) const
@@ -193,3 +247,8 @@ QString Localizer::formatWeight(int gram)
     return i18nc("weight in kilogram", "%1 kg", (int)qRound(gram/1000.0));
 
 }
+
+QString Localizer::formatTemperature(double temperature)
+{
+    return i18nc("temperature", "%1°C", (int)qRound(temperature));
+}
