@@ -4,10 +4,12 @@
 */
 
 #include "passmanager.h"
+
 #include "genericpkpass.h"
+#include "jsonio.h"
 #include "logging.h"
 
-#include <kitinerary_version.h>
+#include <KItinerary/DocumentUtil>
 #include <KItinerary/ExtractorPostprocessor>
 #include <KItinerary/ExtractorValidator>
 #include <KItinerary/JsonLdDocument>
@@ -18,7 +20,6 @@
 #include <KLocalizedString>
 
 #include <QDirIterator>
-#include <QJsonDocument>
 #include <QJsonObject>
 #include <QStandardPaths>
 #include <QUuid>
@@ -44,6 +45,17 @@ QString PassManager::Entry::name() const
     return {};
 }
 
+QDateTime PassManager::Entry::validFrom() const
+{
+    if (JsonLd::isA<KItinerary::ProgramMembership>(data)) {
+        return data.value<KItinerary::ProgramMembership>().validFrom();
+    }
+    if (JsonLd::isA<KItinerary::Ticket>(data)) {
+        return data.value<KItinerary::Ticket>().validFrom();
+    }
+    return {};
+}
+
 QDateTime PassManager::Entry::validUntil() const
 {
     if (JsonLd::isA<KItinerary::ProgramMembership>(data)) {
@@ -79,10 +91,7 @@ PassManager::PassManager(QObject *parent)
     : QAbstractListModel(parent)
     , m_baseTime(QDateTime::currentDateTime())
 {
-#if KITINERARY_VERSION >= QT_VERSION_CHECK(5, 22, 42)
     MergeUtil::registerComparator(isSamePass);
-#endif
-
     load();
 }
 
@@ -96,67 +105,47 @@ int PassManager::rowCount(const QModelIndex &parent) const
     return m_entries.size();
 }
 
-#if KITINERARY_VERSION < QT_VERSION_CHECK(5, 22, 42)
-// ### this should eventually be replaced by custom type support in MergeUtil
-static bool isSameBackwardCompat(const QVariant &lhs, const QVariant &rhs)
-{
-    if (!MergeUtil::isSame(lhs, rhs)) {
-        return false;
-    }
-
-    if (JsonLd::isA<GenericPkPass>(lhs)) {
-        const auto lhsPass = lhs.value<GenericPkPass>();
-        const auto rhsPass = rhs.value<GenericPkPass>();
-        return isSamePass(lhsPass, rhsPass);
-    }
-
-    return true;
-}
-#endif
-
-bool PassManager::import(const QVariant &pass, const QString &id)
+QString PassManager::import(const QVariant &pass, const QString &id)
 {
     // check if this is an element we already have
     for (auto it = m_entries.begin(); it != m_entries.end(); ++it) {
-#if KITINERARY_VERSION < QT_VERSION_CHECK(5, 22, 42)
-        if ((!id.isEmpty() && (*it).id == id) || isSameBackwardCompat((*it).data, pass)) {
-#else
         if ((!id.isEmpty() && (*it).id == id) || MergeUtil::isSame((*it).data, pass)) {
-#endif
             (*it).data = MergeUtil::merge((*it).data, pass);
             write((*it).data, (*it).id);
             const auto idx = index(std::distance(m_entries.begin(), it), 0);
             Q_EMIT dataChanged(idx, idx);
-            return true;
+            Q_EMIT passChanged((*it).id);
+            return (*it).id;
         }
     }
 
     if (JsonLd::isA<KItinerary::ProgramMembership>(pass) || JsonLd::isA<GenericPkPass>(pass) || JsonLd::isA<KItinerary::Ticket>(pass)) {
         Entry entry;
-        entry.id = id.isEmpty() ? QUuid::createUuid().toString() : id;
+        entry.id = id.isEmpty() ? QUuid::createUuid().toString(QUuid::WithoutBraces) : id;
         entry.data = pass;
         if (!write(entry.data, entry.id)) {
-            return false;
+            return {};
         }
 
-        const auto it = std::lower_bound(m_entries.begin(), m_entries.end(), entry, PassComparator(m_baseTime));
+        auto it = std::lower_bound(m_entries.begin(), m_entries.end(), entry, PassComparator(m_baseTime));
         if (it != m_entries.end() && (*it).id == entry.id) {
             (*it).data = entry.data;
             const auto idx = index(std::distance(m_entries.begin(), it), 0);
             Q_EMIT dataChanged(idx, idx);
+            Q_EMIT passChanged((*it).id);
         } else {
             const auto row = std::distance(m_entries.begin(), it);
             beginInsertRows({}, row, row);
-            m_entries.insert(it, std::move(entry));
+            it = m_entries.insert(it, std::move(entry));
             endInsertRows();
         }
-        return true;
+        return (*it).id;
     }
 
-    return false;
+    return {};
 }
 
-bool PassManager::import(const QVector<QVariant> &passes)
+QStringList PassManager::import(const QVector<QVariant> &passes)
 {
     ExtractorPostprocessor postproc;
     postproc.setValidationEnabled(false);
@@ -166,10 +155,13 @@ bool PassManager::import(const QVector<QVariant> &passes)
     ExtractorValidator validator;
     validator.setAcceptedTypes<KItinerary::Ticket, KItinerary::ProgramMembership>();
 
-    bool result = false;
+    QStringList result;
     for (const auto &pass : processed) {
         if (validator.isValidElement(pass)) {
-            result |= import(pass);
+            auto id = import(pass);
+            if (!id.isEmpty()) {
+                result.push_back(id);
+            }
         }
     }
     return result;
@@ -244,7 +236,7 @@ QVariant PassManager::data(const QModelIndex &index, int role) const
             // allows deletion
             return Ticket;
         case PassDataRole:
-            return rawData(entry);
+            return JsonIO::convert(rawData(entry), JsonIO::JSON);
         case NameRole:
             return entry.name();
         case ValidUntilRole:
@@ -253,7 +245,30 @@ QVariant PassManager::data(const QModelIndex &index, int role) const
             if (const auto dt = entry.validUntil(); dt.isValid() && dt < m_baseTime) {
                 return i18nc("no longer valid tickets", "Expired");
             }
+            if (const auto dt = entry.validFrom(); dt.isValid() && dt > m_baseTime) {
+                return i18nc("not yet valid tickets", "Future");
+            }
             return i18nc("not yet expired tickets", "Valid");
+        case ValidRangeLabelRole:
+        {
+            // TODO align this with the time labels in the trip groups? those handle a few more cases...
+            const auto from = entry.validFrom();
+            const auto to = entry.validUntil();
+            if (!from.isValid()) {
+                return {};
+            }
+            const auto days = from.daysTo(to);
+            if (!to.isValid() || days <= 1) {
+                return QLocale().toString(from.date(), QLocale::ShortFormat);
+            }
+            if (days >= 28 && days <= 31) {
+                return QLocale().toString(from, QStringLiteral("MMMM yyyy"));
+            }
+            if (days >= 365 && days <= 366) {
+                return QLocale().toString(from, QStringLiteral("yyyy"));
+            }
+            return i18n("%1 - %2", QLocale().toString(from.date(), QLocale::ShortFormat), QLocale().toString(to.date(), QLocale::ShortFormat));
+        }
     }
 
     return {};
@@ -268,6 +283,7 @@ QHash<int, QByteArray> PassManager::roleNames() const
     r.insert(NameRole, "name");
     r.insert(ValidUntilRole, "validUntil");
     r.insert(SectionRole, "section");
+    r.insert(ValidRangeLabelRole, "validRangeLabel");
     return r;
 }
 
@@ -280,7 +296,7 @@ void PassManager::load()
         entry.id = it.fileName();
         const auto data = rawData(entry);
         if (!data.isEmpty()) {
-            entry.data = JsonLdDocument::fromJsonSingular(QJsonDocument::fromJson(data).object());
+            entry.data = JsonLdDocument::fromJsonSingular(JsonIO::read(data).toObject());
         }
         m_entries.push_back(std::move(entry));
     }
@@ -297,7 +313,7 @@ bool PassManager::write(const QVariant &data, const QString &id) const
         qCWarning(Log) << "Failed to open file:" << f.fileName() << f.errorString();
         return false;
     }
-    f.write(QJsonDocument(JsonLdDocument::toJson(data)).toJson());
+    f.write(JsonIO::write(JsonLdDocument::toJson(data)));
     return true;
 }
 
@@ -312,6 +328,20 @@ QByteArray PassManager::rawData(const Entry &entry) const
     return f.readAll();
 }
 
+void PassManager::update(const QString &passId, const QVariant &pass)
+{
+    auto it = std::find_if(m_entries.begin(), m_entries.end(), [&passId](const auto &lhs) { return lhs.id == passId; });
+    if (it == m_entries.end()) {
+        qWarning() << "couldn't find pass to update!?" << passId << pass;
+        return;
+    }
+    (*it).data = pass;
+    write((*it).data, (*it).id);
+    const auto idx = index(std::distance(m_entries.begin(), it), 0);
+    Q_EMIT dataChanged(idx, idx);
+    Q_EMIT passChanged((*it).id);
+}
+
 bool PassManager::remove(const QString &passId)
 {
     auto it = std::find_if(m_entries.begin(), m_entries.end(), [passId](const auto &entry) {
@@ -344,6 +374,11 @@ bool PassManager::removeRows(int row, int count, const QModelIndex& parent)
     return true;
 }
 
+QVariantList PassManager::documentIds(const QVariant& pass)
+{
+    return DocumentUtil::documentIds(pass);
+}
+
 QString PassManager::basePath()
 {
     return QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1String("/programs/");
