@@ -27,7 +27,7 @@
 #include <QDebug>
 #include <QUrl>
 
-static bool isTrainMode(KPublicTransport::Line::Mode mode)
+bool PublicTransport::isTrainMode(KPublicTransport::Line::Mode mode)
 {
     using namespace KPublicTransport;
     switch (mode) {
@@ -45,7 +45,7 @@ static bool isTrainMode(KPublicTransport::Line::Mode mode)
     }
 }
 
-static bool isBusMode(KPublicTransport::Line::Mode mode)
+bool PublicTransport::isBusMode(KPublicTransport::Line::Mode mode)
 {
     using namespace KPublicTransport;
     switch (mode) {
@@ -97,6 +97,11 @@ QVariant PublicTransport::trainStationFromLocation(const KPublicTransport::Locat
     return PublicTransport::placeFromLocation<KItinerary::TrainStation>(loc);
 }
 
+QVariant PublicTransport::busStationFromLocation(const KPublicTransport::Location &loc) const
+{
+    return PublicTransport::placeFromLocation<KItinerary::BusStation>(loc);
+}
+
 QString PublicTransport::lineIcon(const QVariant &line) const
 {
     using namespace KPublicTransport;
@@ -400,28 +405,6 @@ QVariant PublicTransport::mergeJourney(const QVariant &res, const KPublicTranspo
     return newRes;
 }
 
-bool PublicTransport::isSameMode(const QVariant &res, KPublicTransport::Line::Mode mode)
-{
-    using namespace KPublicTransport;
-
-    if (KItinerary::JsonLd::isA<KItinerary::TrainReservation>(res)) {
-        return isTrainMode(mode);
-    } else if (KItinerary::JsonLd::isA<KItinerary::BusReservation>(res)) {
-        return isBusMode(mode);
-    } else if (KItinerary::JsonLd::isA<KItinerary::FlightReservation>(res)) {
-        return mode == Line::Air;
-    } else if (res.isValid()) {
-        qCWarning(Log) << "unexpected reservation type!?" << res;
-    }
-
-    return false;
-}
-
-bool PublicTransport::isSameMode(const QVariant &res, const KPublicTransport::JourneySection &section)
-{
-    return isSameMode(res, section.route().line().mode());
-}
-
 KPublicTransport::StopoverRequest PublicTransport::stopoverRequestForPlace(const QVariant &place, const QDateTime &dt) const
 {
     KPublicTransport::StopoverRequest req;
