@@ -76,8 +76,12 @@ class TimelineDelegateController : public QObject
     /** Reservation has been canceled (by user or provider, we usually don't know which). */
     Q_PROPERTY(bool isCanceled READ isCanceled NOTIFY contentChanged)
 
-    /** Number of documents attached to the entire batch. */
-    Q_PROPERTY(int documentCount READ documentCount NOTIFY contentChanged)
+    /** Platform sections to the extend known. */
+    Q_PROPERTY(QString departurePlatformSections READ departurePlatformSections NOTIFY layoutChanged)
+    Q_PROPERTY(QString arrivalPlatformSections READ arrivalPlatformSections NOTIFY layoutChanged)
+
+    /** Attached documents of this element. */
+    Q_PROPERTY(QStringList documentIds READ documentIds NOTIFY contentChanged)
 
 public:
     TimelineDelegateController(QObject *parent = nullptr);
@@ -123,11 +127,19 @@ public:
     /** Map page arugments for an element that isn't a location change. */
     Q_INVOKABLE QJSValue mapArguments() const;
 
-    int documentCount() const;
-
     /** Add the current reservation to the calendar @p cal. */
     Q_INVOKABLE void addToCalendar(KCalendarCore::Calendar *cal);
 
+    /** Store vehicle layout data we got from the vehicle layout page. */
+    Q_INVOKABLE void setVehicleLayout(const KPublicTransport::Stopover &stopover, bool arrival);
+
+    /** Platform section information. */
+    QString departurePlatformSections() const;
+    QString arrivalPlatformSections() const;
+
+    /** Ids of attached documents. */
+    QStringList documentIds() const;
+
 Q_SIGNALS:
     void setupChanged();
     void batchIdChanged();
@@ -139,6 +151,7 @@ Q_SIGNALS:
     void journeyChanged();
     void previousLocationChanged();
     void connectionWarningChanged();
+    void layoutChanged();
 
 private:
     void setCurrent(bool current, const QVariant &res = {});
