@@ -9,10 +9,7 @@
 #include "locationhelper.h"
 #include "timelinemodel.h"
 
-#if HAVE_KHOLIDAYS
-#include <kholidays_version.h>
 #include <KHolidays/HolidayRegion>
-#endif
 
 #include <KLocalizedString>
 
@@ -77,26 +74,19 @@ bool TimelineSectionDelegateController::isToday() const
 
 QString TimelineSectionDelegateController::subTitle() const
 {
-#if HAVE_KHOLIDAYS
     if (!m_holidays.isEmpty()) {
         return m_holidays.at(0).name();
     }
-#endif
 
     return {};
 }
 
 bool TimelineSectionDelegateController::isHoliday() const
 {
-#if HAVE_KHOLIDAYS
     // non-workdays being first is ensured recheckHoliday
     return !m_holidays.isEmpty() && m_holidays.at(0).dayType() == KHolidays::Holiday::NonWorkday;
-#else
-    return false;
-#endif
 }
 
-#if HAVE_KHOLIDAYS
 // ATTENTION the HolidayRegion methods we call here are very expensive!
 static std::optional<KHolidays::HolidayRegion> cachedHolidayRegion(const QString &regionCode)
 {
@@ -120,7 +110,6 @@ static std::optional<KHolidays::HolidayRegion> cachedHolidayRegion(const QString
     s_cache.insert(regionCode, {});
     return {};
 }
-#endif
 
 void TimelineSectionDelegateController::recheckHoliday()
 {
@@ -128,7 +117,6 @@ void TimelineSectionDelegateController::recheckHoliday()
         return;
     }
 
-#if HAVE_KHOLIDAYS
     m_holidays.clear();
 
     const auto regionCode = LocationHelper::regionCode(m_model->locationAtTime(QDateTime(m_date, {})));
@@ -136,19 +124,13 @@ void TimelineSectionDelegateController::recheckHoliday()
         return;
     }
 
-
     if (const auto holidayRegion = cachedHolidayRegion(regionCode); holidayRegion) {
-#if KHOLIDAYS_VERSION < QT_VERSION_CHECK(5, 95, 0)
-        m_holidays = holidayRegion->holidays(m_date);
-#else
         m_holidays = holidayRegion->rawHolidaysWithAstroSeasons(m_date);
-#endif
         // prioritize non-workdays
         std::sort(m_holidays.begin(), m_holidays.end(), [](const auto &lhs, const auto &rhs) {
             return lhs.dayType() == KHolidays::Holiday::NonWorkday && rhs.dayType() == KHolidays::Holiday::Workday;
         });
     }
-#endif
 }
 
 #include "moc_timelinesectiondelegatecontroller.cpp"
