@@ -50,7 +50,7 @@ QString ContentResolver::fileName(const QUrl &url)
     auto cursor = cs.callObjectMethod("query", Jni::signature<android::database::Cursor(android::net::Uri, java::lang::String[], java::lang::String, java::lang::String[], java::lang::String)>(), uri.object<jobject>(), 0, 0, 0, 0);
 
     const QAndroidJniObject DISPLAY_NAME = OpenableColumns::DISPLAY_NAME;
-    const auto nameIndex = cursor.callMethod<jint>("getColumnIndex", Jni::signature<int(java::lang::String)>(), DISPLAY_NAME.object());
-    cursor.callMethod<jboolean>("moveToFirst", Jni::signature<bool()>());
+    const auto nameIndex = cursor.callMethod<jint>("getColumnIndex", (const char*)Jni::signature<int(java::lang::String)>(), DISPLAY_NAME.object());
+    cursor.callMethod<jboolean>("moveToFirst", (const char*)Jni::signature<bool()>());
     return cursor.callObjectMethod("getString", Jni::signature<java::lang::String(int)>(), nameIndex).toString();
 }
